@@ -157,7 +157,7 @@ func TestEventThrottler(t *testing.T) {
 
 func BenchmarkGetGPUProcessStats(b *testing.B) {
 	b.ReportAllocs()
-	for i := 0; i < b.N; i++ {
+	for b.Loop() {
 		_ = GetGPUProcessStats()
 	}
 }
